#########################################################################################
# Source: https://github.com/NanoComp/meep/blob/master/python/materials.py
##########################################################################################

um_scale = 1.0

#------------------------------------------------------------------
# crystalline silicon (c-Si) from A. Deinega et al., J. Optical Society of America A, Vol. 28, No. 5, pp. 770-77 (2011)
# based on experimental data for intrinsic silicon at T=300K from M.A. Green and M. Keevers, Progress in Photovoltaics, Vol. 3, pp. 189-92 (1995)
# wavelength range: 0.4 - 1.0 um

cSi_range = FreqRange(min = um_scale, max = um_scale / 0.4)
cSi_frq1 = 3.64 / um_scale
cSi_gam1 = 0
cSi_sig1 = 8
cSi_frq2 = 2.76 / um_scale
cSi_gam2 = 2 * 0.063 / um_scale
cSi_sig2 = 2.85
cSi_frq3 = 1.73 / um_scale
cSi_gam3 = 2 * 2.5 / um_scale
cSi_sig3 = -0.107

cSi_susc =
    [
        LorentzianSusceptibility(frequency = cSi_frq1, gamma = cSi_gam1, sigma = cSi_sig1),
        LorentzianSusceptibility(frequency = cSi_frq2, gamma = cSi_gam2, sigma = cSi_sig2),
        LorentzianSusceptibility(frequency = cSi_frq3, gamma = cSi_gam3, sigma = cSi_sig3)
    ]

cSi = Medium(epsilon_model = DispersionModel(inf = 1.0, susceptibilities = cSi_susc, valid_freq_range = cSi_range))

#------------------------------------------------------------------
# amorphous silicon (a-Si) from Horiba Technical Note 08: Lorentz Dispersion Model
# ref: http://www.horiba.com/fileadmin/uploads/Scientific/Downloads/OpticalSchool_CN/TN/ellipsometer/Lorentz_Dispersion_Model.pdf
# wavelength range: 0.21 - 0.83 um

aSi_range = FreqRange(min = um_scale / 0.83, max = um_scale / 0.21)

aSi_frq1 = 1 / (0.315481407124682 * um_scale)
aSi_gam1 = 1 / (0.645751005208333 * um_scale)
aSi_sig1 = 14.571

aSi_susc =
    [
        LorentzianSusceptibility(frequency = aSi_frq1, gamma = aSi_gam1, sigma = aSi_sig1)
    ]

aSi = Medium(epsilon_model = DispersionModel(inf = 3.109, susceptibilities = aSi_susc, valid_freq_range = aSi_range))
#------------------------------------------------------------------
# hydrogenated amorphous silicon (a-Si:H) from Horiba Technical Note 08: Lorentz Dispersion Model
# ref: http://www.horiba.com/fileadmin/uploads/Scientific/Downloads/OpticalSchool_CN/TN/ellipsometer/Lorentz_Dispersion_Model.pdf
# wavelength range: 0.21 - 0.83 um

aSi_H_range = FreqRange(min = um_scale / 0.83, max = um_scale / 0.21)

aSi_H_frq1 = 1 / (0.334189199460916 * um_scale)
aSi_H_gam1 = 1 / (0.579365387850467 * um_scale)
aSi_H_sig1 = 12.31

aSi_H_susc =
    [
        LorentzianSusceptibility(frequency = aSi_H_frq1, gamma = aSi_H_gam1, sigma = aSi_H_sig1)
    ]

aSi_H = Medium(epsilon_model = DispersionModel(inf = 3.22, susceptibilities = aSi_H_susc, valid_freq_range = aSi_H_range))
#------------------------------------------------------------------
# silicon nitride (Si3N4) from H. R. Philipp, J. Electrochemical Society 120, 295-300, 1973
# ref: https://refractiveindex.info/?shelf=main&book=Si3N4&page=Philipp
# wavelength range: 0.207 - 1.24 um

Si3N4_VISNIR_range = FreqRange(min = um_scale / 1.24, max = um_scale / 0.207)

Si3N4_VISNIR_frq1 = 1 / (0.13967 * um_scale)
Si3N4_VISNIR_gam1 = 0
Si3N4_VISNIR_sig1 = 2.8939

Si3N4_VISNIR_susc =
    [
        LorentzianSusceptibility(frequency = Si3N4_VISNIR_frq1, gamma = Si3N4_VISNIR_gam1, sigma = Si3N4_VISNIR_sig1)
    ]

Si3N4_VISNIR = Medium(epsilon_model = DispersionModel(inf = 1.0, susceptibilities = Si3N4_VISNIR_susc, valid_freq_range = Si3N4_VISNIR_range))

#------------------------------------------------------------------
# silicon nitride (Si3N4) from K. Luke, et. al., Optics Letters, Vol. 40, pp. 4823-26, 2015
# ref: https://refractiveindex.info/?shelf=main&book=Si3N4&page=Luke
# wavelength range: 0.310 - 5.504 um

Si3N4_NIR_range = FreqRange(min = um_scale / 5.504, max = um_scale / 0.310)

Si3N4_NIR_frq1 = 1 / (0.1353406 * um_scale)
Si3N4_NIR_gam1 = 0
Si3N4_NIR_sig1 = 3.0249
Si3N4_NIR_frq2 = 1 / (1239.842 * um_scale)
Si3N4_NIR_gam2 = 0
Si3N4_NIR_sig2 = 40314

Si3N4_NIR_susc =
    [
        LorentzianSusceptibility(frequency = Si3N4_NIR_frq1, gamma = Si3N4_NIR_gam1, sigma = Si3N4_NIR_sig1),
        LorentzianSusceptibility(frequency = Si3N4_NIR_frq2, gamma = Si3N4_NIR_gam2, sigma = Si3N4_NIR_sig2)
    ]

Si3N4_NIR = Medium(epsilon_model =
DispersionModel(inf = 1.0, susceptibilities = Si3N4_NIR_susc, valid_freq_range = Si3N4_NIR_range))